@@ -4,6 +4,9 @@
 
 #include "utils.h"
 
+#include <DSysInfo>
+DCORE_USE_NAMESPACE
+
 #include <QFontDatabase>
 #include <QImageReader>
 
@@ -11,8 +14,10 @@ QHash<QString, QPixmap> Utils::m_imgCacheHash;
 QHash<QString, QString> Utils::m_fontNameCache;
 QString Utils::cpuModeName;
 
-const char kLauncherService[] = "com.deepin.dde.daemon.Launcher";
-const char kLauncherIface[] = "/com/deepin/dde/daemon/Launcher";
+const char kLauncherServiceV20[] = "com.deepin.dde.daemon.Launcher";
+const char kLauncherIfaceV20[] = "/com/deepin/dde/daemon/Launcher";
+const char kLauncherServiceV23[] = "org.deepin.dde.daemon.Launcher1";
+const char kLauncherIfaceV23[] = "/org/deepin/dde/daemon/Launcher1";
 
 //标题映射表
 const int langCount = 5;
@@ -39,7 +44,8 @@ QString languageArr[][langCount] = {
     {"systeminfo", "系统信息", "System Info", "系統訊息", "系統資訊"},
     {"License activator", "授权管理", "Authorization Management", "授權管理", "授權管理"},
     {"commoninfo", "通用设置", "General Settings", "通用設置", "一般設定"},
-    {"touchscreen", "触控屏设置", "Touch Screen", "觸控屏設置", "觸控屏設定"}};
+    {"touchscreen", "触控屏设置", "Touch Screen", "觸控屏設置", "觸控屏設定"}
+};
 
 struct ReplyStruct {
     QString m_desktop;
@@ -49,6 +55,7 @@ struct ReplyStruct {
 
     qint64 m_categoryId;
     qint64 m_installedTime;
+    QStringList m_appmessage;
 };
 
 Q_DECLARE_METATYPE(ReplyStruct)
@@ -63,7 +70,10 @@ QDBusArgument &operator<<(QDBusArgument &argument, const ReplyStruct &info)
 {
     argument.beginStructure();
     argument << info.m_desktop << info.m_name << info.m_key << info.m_iconKey;
-    argument << info.m_categoryId << info.m_installedTime;
+    if (DSysInfo::majorVersion() == "23")
+        argument << info.m_categoryId << info.m_installedTime << info.m_appmessage;
+    else
+        argument << info.m_categoryId << info.m_installedTime;
     argument.endStructure();
     return argument;
 }
@@ -78,7 +88,10 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, ReplyStruct &info
 {
     argument.beginStructure();
     argument >> info.m_desktop >> info.m_name >> info.m_key >> info.m_iconKey;
-    argument >> info.m_categoryId >> info.m_installedTime;
+    if (DSysInfo::majorVersion() == "23")
+        argument >> info.m_categoryId >> info.m_installedTime >> info.m_appmessage;
+    else
+        argument >> info.m_categoryId >> info.m_installedTime;
     argument.endStructure();
     return argument;
 }
@@ -164,13 +177,14 @@ QList<AppInfo> Utils::launcherInterface()
     qRegisterMetaType<QList<ReplyStruct>>("a");
     qDBusRegisterMetaType<QList<ReplyStruct>>();
 
-    QDBusInterface iface(kLauncherService,
-                         kLauncherIface,
-                         kLauncherService,
-                         QDBusConnection::sessionBus());
+    bool bV23 = DSysInfo::majorVersion() == "23";
+    QString sLauncherService = bV23 ? kLauncherServiceV23 : kLauncherServiceV20;
+    QString sLauncherIface = bV23 ? kLauncherIfaceV23 : kLauncherIfaceV20;
+    QDBusInterface iface(sLauncherService, sLauncherIface, sLauncherService, QDBusConnection::sessionBus());
     //root权限下此dbus接口无效...
     if (!iface.isValid()) {
         qDebug() << qPrintable(QDBusConnection::sessionBus().lastError().message());
+        qDebug() << QString("majorVersion:%1, servie:%2 iface:%3").arg(DSysInfo::majorVersion()).arg(sLauncherService).arg(sLauncherIface);
         return applist;
 //        exit(1);
     }
@@ -196,6 +210,7 @@ QList<AppInfo> Utils::launcherInterface()
         return applist;
     } else {
         qDebug() << "GetAllItemInfos fail! " << reply.error().message();
+        qDebug() << QString("majorVersion:%1, servie:%2 iface:%3").arg(DSysInfo::majorVersion()).arg(sLauncherService).arg(sLauncherIface);
         return applist;
     }
 }
@@ -207,17 +222,58 @@ QList<AppInfo> Utils::launcherInterface()
  */
 bool Utils::judgeWayLand()
 {
-   auto env = QProcessEnvironment::systemEnvironment();
+    auto env = QProcessEnvironment::systemEnvironment();
 
-   QString XDG_SESSION_TYPE = env.value(QStringLiteral("XDG_SESSION_TYPE"));
+    QString XDG_SESSION_TYPE = env.value(QStringLiteral("XDG_SESSION_TYPE"));
 
-   QString WAYLAND_DISPLAY = env.value(QStringLiteral("WAYLAND_DISPLAY"));
+    QString WAYLAND_DISPLAY = env.value(QStringLiteral("WAYLAND_DISPLAY"));
 
-   if (XDG_SESSION_TYPE == QLatin1String("wayland") || WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)){
-      return true;
-   }
+    if (XDG_SESSION_TYPE == QLatin1String("wayland") || WAYLAND_DISPLAY.contains(QLatin1String("wayland"), Qt::CaseInsensitive)) {
+        return true;
+    }
 
-   return false;
+    return false;
+}
+
+QStringList Utils::getMdsourcePath()
+{
+    QStringList sourcePath;
+#ifdef LINGLONG_BUILD
+    QStringList pathlist = getEnvsourcePath();
+    for (int i = 0; i < pathlist.size(); ++i) {
+        if (pathlist[i].contains("persistent") || pathlist[i].contains("usr/share")) {
+            sourcePath.push_back(pathlist[i] + "/deepin-manual/manual-assets");
+            qDebug() << " all MD source path : " << sourcePath.last();
+        }
+    }
+#else
+    sourcePath.push_back(DMAN_MANUAL_DIR);
+#endif
+    return sourcePath;
+}
+
+QStringList Utils::getEnvsourcePath()
+{
+    QStringList pathlist = QString(qgetenv("XDG_DATA_DIRS")).split(':');
+    if (pathlist.size() == 1 && pathlist[0].isEmpty())
+        pathlist[0] = "/usr/share";
+    qDebug() << " all source path : " << pathlist;
+    return pathlist;
+}
+
+QString Utils::getDesktopFilePath(const QString &desktopname)
+{
+    // 遍历XDG_DATA_DIRS中的路径，找寻指定desktop文件
+    QStringList pathList = getEnvsourcePath();
+    foreach (auto path, pathList) {
+        QString filepath = path + QString("/applications/%1.desktop").arg(desktopname);
+        QFile file(filepath);
+        if (file.exists()) {
+            return filepath;
+        }
+    }
+
+    return "";
 }
 
 /**
@@ -240,62 +296,62 @@ QStringList Utils::getSystemManualList()
     };
 
     QStringList app_list_;
+    QStringList strMANUAL_DIR_list = Utils::getMdsourcePath();
     //调用dbus服务获取系统安装应用
     const AppInfoList list = launcherInterface();
-    const QStringList applicationList = QDir(QString("%1/application/").arg(DMAN_MANUAL_DIR)).entryList();
-    const QStringList systemList = QDir(QString("%1/system/").arg(DMAN_MANUAL_DIR)).entryList();
-
-    QString oldMdPath = DMAN_MANUAL_DIR;
-
-#if (DTK_VERSION > DTK_VERSION_CHECK(5, 4, 12, 0))
-    if (Dtk::Core::DSysInfo::UosServer == Dtk::Core::DSysInfo::uosType()) {
-        oldMdPath += "/server";
-    } else if (Dtk::Core::DSysInfo::UosHome == Dtk::Core::DSysInfo::uosEditionType()) {
-        oldMdPath += "/personal";
-    } else if (Dtk::Core::DSysInfo::UosEducation == Dtk::Core::DSysInfo::uosEditionType()) {
-        oldMdPath += "/education";
-    } else if (Dtk::Core::DSysInfo::UosCommunity == Dtk::Core::DSysInfo::uosEditionType()) {
-        oldMdPath += "/community";
-    } else {
-        oldMdPath += "/professional";
-    }
-#else
-    Dtk::Core::DSysInfo::DeepinType nType = Dtk::Core::DSysInfo::deepinType();
-    if (Dtk::Core::DSysInfo::DeepinServer == nType) {
-        oldMdPath += "/server";
-    } else if (Dtk::Core::DSysInfo::DeepinPersonal == nType) {
-        oldMdPath += "/personal";
-    } else {
-        if (Dtk::Core::DSysInfo::isCommunityEdition()) {
-            oldMdPath += "/community";
-        } else {
-            oldMdPath += "/professional";
-        }
-    }
-
-#endif
-    const QStringList oldAppList = QDir(oldMdPath).entryList();
-
     QMultiMap<qlonglong, AppInfo> appMap;
     for (int var = 0; var < list.size(); ++var) {
         appMap.insert(list.at(var).installed_time, list.at(var));
     }
     //安装时间相同时,按名称排序
     QList<AppInfo> listApp = sortAppList(appMap);
+    foreach (auto strMANUAL_DIR, strMANUAL_DIR_list) {
+        const QStringList applicationList = QDir(QString("%1/application/").arg(strMANUAL_DIR)).entryList();
+        const QStringList systemList = QDir(QString("%1/system/").arg(strMANUAL_DIR)).entryList();
+        QString oldMdPath = strMANUAL_DIR;
 
-    //比对存在帮助md文件的应用
-    for (int i = 0; i < listApp.size(); ++i) {
-        const QString app_name = kAppNameMap.value(listApp.at(i).key, listApp.at(i).key);
-        if ((applicationList.contains(app_name) || oldAppList.contains(app_name))  && app_list_.indexOf(app_name) == -1) {
-            app_list_.append(app_name);
+#if (DTK_VERSION > DTK_VERSION_CHECK(5, 4, 12, 0))
+        if (Dtk::Core::DSysInfo::UosServer == Dtk::Core::DSysInfo::uosType()) {
+            oldMdPath += "/server";
+        } else if (Dtk::Core::DSysInfo::UosHome == Dtk::Core::DSysInfo::uosEditionType()) {
+            oldMdPath += "/personal";
+        } else if (Dtk::Core::DSysInfo::UosEducation == Dtk::Core::DSysInfo::uosEditionType()) {
+            oldMdPath += "/education";
+        } else if (Dtk::Core::DSysInfo::UosCommunity == Dtk::Core::DSysInfo::uosEditionType()) {
+            oldMdPath += "/community";
+        } else {
+            oldMdPath += "/professional";
         }
+#else
+        Dtk::Core::DSysInfo::DeepinType nType = Dtk::Core::DSysInfo::deepinType();
+        if (Dtk::Core::DSysInfo::DeepinServer == nType) {
+            oldMdPath += "/server";
+        } else if (Dtk::Core::DSysInfo::DeepinPersonal == nType) {
+            oldMdPath += "/personal";
+        } else {
+            if (Dtk::Core::DSysInfo::isCommunityEdition()) {
+                oldMdPath += "/community";
+            } else {
+                oldMdPath += "/professional";
+            }
+        }
+
+#endif
+        const QStringList oldAppList = QDir(oldMdPath).entryList();
+
+        //比对存在帮助md文件的应用
+        for (int i = 0; i < listApp.size(); ++i) {
+            const QString app_name = kAppNameMap.value(listApp.at(i).key, listApp.at(i).key);
+            if ((applicationList.contains(app_name) || oldAppList.contains(app_name))  && app_list_.indexOf(app_name) == -1) {
+                app_list_.append(app_name);
+            }
+        }
+        if (systemList.contains("dde") || oldAppList.contains("dde")) {
+            app_list_.append("dde");
+        }
+        qDebug() << "exist app list: " << app_list_ << ", count:" << app_list_.size();
     }
     app_list_.append("DeepinAIAssistant"); //语音助手无法通过launcherInterface获取目前只能手动添加
-    if (systemList.contains("dde") || oldAppList.contains("dde")) {
-        app_list_.append("dde");
-    }
-
-    qDebug() << "exist app list: " << app_list_ << ", count:" << app_list_.size();
     return app_list_;
 }
 
@@ -304,10 +360,9 @@ QStringList Utils::getSystemManualList()
  * @return
  * @note　获取系统版本信息
  */
-QString Utils::getSystemManualDir()
+QStringList Utils::getSystemManualDir()
 {
-    QString strMANUAL_DIR = DMAN_MANUAL_DIR;
-    return strMANUAL_DIR;
+    return Utils::getMdsourcePath();
 }
 
 /**
