@@ -1,8 +1,10 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="bo">
 <context>
     <name>ManualProxy</name>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="306"/>
+        <location filename="../src/view/manual_proxy.cpp" line="311"/>
         <source>Desktop Environment</source>
         <translation>ཅོག་ངོས་ཁོར་ཡུག</translation>
     </message>
@@ -10,68 +12,68 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/app/dman.cpp" line="71"/>
+        <location filename="../src/app/dman.cpp" line="107"/>
         <source>Manual</source>
         <translation>རོགས་རམ་ལག་དེབ།</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="72"/>
+        <location filename="../src/app/dman.cpp" line="108"/>
         <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
         <translation>རོགས་རམ་ལག་དེབ་ནི་སྤྱོད་མཁན་གྱིས་བཀོལ་སྤྱོད་མ་ལག་དང་དེའི་མ་ལག་ཉེར་སྤྱོད་ལ་རྒྱུས་ལོན་བྱེད་རོགས་བྱེད་པ་དང་། ཞིབ་ཕྲའི་སྤྱོད་ཐབས་དང་ནུས་པའི་གསལ་བཤད་འདོན་སྤྲོད་བྱེད་ཐུབ།</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
         <source>System</source>
         <translation>མ་ལག</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
         <source>Applications</source>
         <translation>ཉེར་སྤྱོད།</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="38"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
         <source>No search results</source>
         <translation>འཚོལ་ཞིབ་བྱས་འབྲས་མེད།</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="41"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
         <source>Home</source>
         <translation>གཙོ་ངོས་སུ་ཕྱིར་ལོག་པ།</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="43"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
         <source>  result</source>
         <translation>འབྲས་བུ།</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="44"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
         <source>  results</source>
         <translation>འབྲས་བུ།</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="513"/>
+        <location filename="../src/view/web_window.cpp" line="591"/>
         <source>Search</source>
         <translation>འཚོལ་ཞིབ།</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="516"/>
+        <location filename="../src/view/web_window.cpp" line="594"/>
         <source>Support</source>
         <translation>ཞབས་ཞུ་དང་རོགས་སྐྱོར།</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="250"/>
+        <location filename="../src/view/web_window.cpp" line="275"/>
         <source>The content was updated</source>
         <translation>མིག་སྔའི་ནང་དོན་གསར་བརྗེ་བྱས་ཟིན།</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="691"/>
+        <location filename="../src/view/web_window.cpp" line="795"/>
         <source>Copy</source>
         <translation>པར་སློག</translation>
     </message>
     <message>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="174"/>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="259"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
         <source>Search for &quot;%1&quot; in the full text</source>
         <translation>ཡིག་ཆ་ཚང་མའི་ནང་དུ་“%1”འཚོལ་བ།</translation>
     </message>
@@ -79,14 +81,14 @@
 <context>
     <name>WebWindow</name>
     <message>
-        <location filename="../src/view/web_window.cpp" line="616"/>
+        <location filename="../src/view/web_window.cpp" line="729"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="641"/>
+        <location filename="../src/view/web_window.cpp" line="744"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
